@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -204,8 +204,21 @@ class OriginView(CoreOfficeMasterView):
             return text
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    OriginCountryView = kwargs.get('OriginCountryView', base['OriginCountryView'])
     OriginCountryView.defaults(config)
+
+    OriginStateProvinceView = kwargs.get('OriginStateProvinceView', base['OriginStateProvinceView'])
     OriginStateProvinceView.defaults(config)
+
+    OriginRegionView = kwargs.get('OriginRegionView', base['OriginRegionView'])
     OriginRegionView.defaults(config)
+
+    OriginView = kwargs.get('OriginView', base['OriginView'])
     OriginView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
