@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -135,5 +135,12 @@ class SuperDepartmentView(base.DepartmentView):
         g.set_sort_defaults('number')
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    SuperDepartmentView = kwargs.get('SuperDepartmentView', base['SuperDepartmentView'])
     SuperDepartmentView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
