@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -127,5 +127,12 @@ class TransactionDetailView(CoreOfficeMasterView):
         cls._defaults(config)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    TransactionDetailView = kwargs.get('TransactionDetailView', base['TransactionDetailView'])
     TransactionDetailView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
