@@ -93,13 +93,4 @@ class PersonView(base.PersonView):
 
 
 def includeme(config):
-
-    # autocomplete
-    config.add_route('people.autocomplete', '/people/autocomplete')
-    config.add_view(base.PeopleAutocomplete, route_name='people.autocomplete',
-                    renderer='json', permission='people.list')
-    config.add_route('people.autocomplete.employees', '/people/autocomplete/employees')
-    config.add_view(base.PeopleEmployeesAutocomplete, route_name='people.autocomplete.employees',
-                    renderer='json', permission='people.list')
-
     PersonView.defaults(config)
